@@ -1,12 +1,14 @@
-# WordNet::Similarity::edge.pm version 0.05
-# (Updated 06/03/2003 -- Sid)
+# WordNet::Similarity::edge.pm version 0.06
+# (Updated 10/10/2003 -- Sid)
 #
 # Semantic Similarity Measure package implementing the simple
 # edge counting semantic relatedness measure.
 #
 # Copyright (c) 2003,
-# Siddharth Patwardhan, University of Minnesota, Duluth
-# patw0006@d.umn.edu
+#
+# Siddharth Patwardhan, University of Utah, Salt Lake City
+# sidd@cs.utah.edu
+#
 # Ted Pedersen, University of Minnesota, Duluth
 # tpederse@d.umn.edu
 #
@@ -44,7 +46,7 @@ use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 
 @EXPORT = ();
 
-$VERSION = '0.05';
+$VERSION = '0.06';
 
 
 # 'new' method for the edge class... creates and returns a WordNet::Similarity::edge object.
@@ -84,6 +86,7 @@ sub new
     $self->{'traceString'} .= "WordNet::Similarity::edge object created:\n";
     $self->{'traceString'} .= "trace :: ".($self->{'trace'})."\n" if(defined $self->{'trace'});
     $self->{'traceString'} .= "cache :: ".($self->{'doCache'})."\n" if(defined $self->{'doCache'});
+    $self->{'traceString'} .= "Cache Size :: ".($self->{'maxCacheSize'})."\n" if(defined $self->{'maxCacheSize'});
     # [/trace]
 
     return $self;
@@ -157,6 +160,14 @@ sub _initialize
 			$self->{'doCache'} = 1;
 			$self->{'doCache'} = $tmp if($tmp =~ /^[01]$/);
 		    }
+		    elsif(m/^(?:max)?CacheSize::(.*)/i) 
+		    {
+			my $mcs = $1;
+			$self->{'maxCacheSize'} = 1000;
+			$self->{'maxCacheSize'} = $mcs
+			    if(defined ($mcs) && $mcs =~ m/^\d+$/);
+			$self->{'maxCacheSize'} = 0 if($self->{'maxCacheSize'} < 0);
+		    }
 		    elsif($_ ne "")
 		    {
 			s/::.*//;
@@ -549,7 +560,7 @@ __END__
 =head1 NAME
 
 WordNet::Similarity::edge - Perl module for computing semantic relatedness
-of word senses by counting edges in the WordNet hierarchy.
+of word senses by counting edges in the WordNet 'is-a' hierarchy.
 
 =head1 SYNOPSIS
 
@@ -573,7 +584,7 @@ of word senses by counting edges in the WordNet hierarchy.
 
 This module computes the semantic relatedness of word senses by counting 
 the number of edges between the senses in the 'is-a' hierarchy of WordNet. 
-Since, the longer path lenghts indicate less relatedness, the value 
+Since, the longer path lengths indicate less relatedness, the value 
 obtained is inverted in order to get a value of semantic relatedness.
 
 =head1 USAGE
@@ -591,7 +602,7 @@ See the WordNet::Similarity(3) documentation for details of these methods.
 =head1 TYPICAL USAGE EXAMPLES
 
 To create an object of the edge measure, we would have the following
-lines of code in the perl program. 
+lines of code in the Perl program.
 
    use WordNet::Similarity::edge;
    $measure = WordNet::Similarity::edge->new($wn, '/home/sid/edge.conf');
@@ -607,7 +618,7 @@ as well as any other error/warning may be tested.
    ($err, $errString) = $measure->getError();
    die $errString."\n" if($err);
 
-To find the sematic relatedness of the first sense of the noun 'car' and
+To find the semantic relatedness of the first sense of the noun 'car' and
 the second sense of the noun 'bus' using the measure, we would write
 the following piece of code:
 
@@ -622,13 +633,13 @@ traces are turned off.
 
 =head1 CONFIGURATION FILE
 
-The behaviour of the measures of semantic relatedness can be controlled by
+The behavior of the measures of semantic relatedness can be controlled by
 using configuration files. These configuration files specify how certain
 parameters are initialized within the object. A configuration file may be
-specififed as a parameter during the creation of an object using the new
+specified as a parameter during the creation of an object using the new
 method. The configuration files must follow a fixed format.
 
-Every configuration file starts the name of the module ON THE FIRST LINE of
+Every configuration file starts with the name of the module ON THE FIRST LINE of
 the file. For example, a configuration file for the edge module will have
 on the first line 'WordNet::Similarity::edge'. This is followed by the various
 parameters, each on a new line and having the form 'name::value'. The
@@ -651,21 +662,24 @@ word#pos#offset strings.
 which case it takes the value 1, i.e. switches 'on' caching. A value of 
 0 switches caching 'off'. By default caching is enabled.
 
+(c) 'maxCacheSize::' -- takes a non-negative integer value. The value indicates
+the size of the cache, used for storing the computed relatedness value.
+
 =head1 SEE ALSO
 
 perl(1), WordNet::Similarity(3), WordNet::QueryData(3)
 
-http://www.d.umn.edu/~patw0006
+http://www.cs.utah.edu/~sidd
 
 http://www.cogsci.princeton.edu/~wn
 
-http://www.ai.mit.edu/people/jrennie/WordNet
+http://www.ai.mit.edu/~jrennie/WordNet
 
 http://groups.yahoo.com/group/wn-similarity
 
 =head1 AUTHORS
 
-  Siddharth Patwardhan, <patw0006@d.umn.edu>
+  Siddharth Patwardhan, <sidd@cs.utah.edu>
   Ted Pedersen, <tpederse@d.umn.edu>
 
 =head1 COPYRIGHT AND LICENSE
