@@ -1,12 +1,14 @@
-# WordNet::Similarity::hso.pm version 0.05
-# (Updated 06/03/2003 -- Sid)
+# WordNet::Similarity::hso.pm version 0.06
+# (Updated 10/10/2003 -- Sid)
 #
-# Semantic Similarity Measure package implementing the semantic 
-# distance measure described by Hirst and St.Onge (1998).
+# Semantic Similarity Measure package implementing the measure 
+# described by Hirst and St.Onge (1998).
 #
 # Copyright (c) 2003,
-# Siddharth Patwardhan, University of Minnesota, Duluth
-# patw0006@d.umn.edu
+#
+# Siddharth Patwardhan, University of Utah, Salt Lake City
+# sidd@cs.utah.edu
+#
 # Ted Pedersen, University of Minnesota, Duluth
 # tpederse@d.umn.edu
 #
@@ -23,8 +25,8 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to 
 #
-# The Free Software Foundation, Inc., 
-# 59 Temple Place - Suite 330, 
+# The Free Software Foundation, Inc.,
+# 59 Temple Place - Suite 330,
 # Boston, MA  02111-1307, USA.
 
 
@@ -44,7 +46,7 @@ use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 
 @EXPORT = ();
 
-$VERSION = '0.05';
+$VERSION = '0.06';
 
 
 # 'new' method for the hso class... creates and returns a WordNet::Similarity::hso object.
@@ -60,7 +62,7 @@ sub new
 
     # The name of my class.
     $className = shift;
-    
+
     # Initialize the error string and the error level.
     $self->{'errorString'} = "";
     $self->{'error'} = 0;
@@ -75,6 +77,9 @@ sub new
 	$self->{'error'} = 2;
     }
 
+    # queryWord was broken in older versions of WordNet::QueryData
+    $wn->VERSION(1.30) if $wn;
+
     # Bless object, initialize it and return it.
     bless($self, $className);
     $self->_initialize(shift) if($self->{'error'} < 2);
@@ -84,6 +89,7 @@ sub new
     $self->{'traceString'} .= "WordNet::Similarity::hso object created:\n";
     $self->{'traceString'} .= "trace :: ".($self->{'trace'})."\n" if(defined $self->{'trace'});
     $self->{'traceString'} .= "cache :: ".($self->{'doCache'})."\n" if(defined $self->{'doCache'});
+    $self->{'traceString'} .= "Cache Size :: ".($self->{'maxCacheSize'})."\n" if(defined $self->{'maxCacheSize'});
     # [/trace]
 
     return $self;
@@ -158,6 +164,14 @@ sub _initialize
 			$self->{'doCache'} = 1;
 			$self->{'doCache'} = $tmp if($tmp =~ /^[01]$/);
 		    }
+		    elsif(m/^(?:max)?CacheSize::(.*)/i) 
+		    {
+			my $mcs = $1;
+			$self->{'maxCacheSize'} = 1000;
+			$self->{'maxCacheSize'} = $mcs
+			    if(defined ($mcs) && $mcs =~ m/^\d+$/);
+			$self->{'maxCacheSize'} = 0 if($self->{'maxCacheSize'} < 0);
+		    }
 		    elsif($_ ne "")
 		    {
 			s/::.*//;
@@ -539,10 +553,10 @@ sub getHorizontalOffsetsPOS
 	return @offsets;
     }
     $wordForm = $wn->getSense($offset,$pos);
-    @synsets = $wn->query($wordForm, "also");
-    push @synsets, $wn->query($wordForm, "ants");
+    @synsets = $wn->queryWord($wordForm, "also");
+    push @synsets, $wn->queryWord($wordForm, "ants");
     push @synsets, $wn->querySense($wordForm, "attr");
-    push @synsets, $wn->query($wordForm, "pert");
+    push @synsets, $wn->queryWord($wordForm, "pert");
     push @synsets, $wn->querySense($wordForm, "sim");
     foreach $synset (@synsets)
     {
@@ -978,7 +992,7 @@ See the WordNet::Similarity(3) documentation for details of these methods.
 =head1 TYPICAL USAGE EXAMPLES
 
 To create an object of the hso measure, we would have the following
-lines of code in the perl program. 
+lines of code in the Perl program. 
 
    use WordNet::Similarity::hso;
    $measure = WordNet::Similarity::hso->new($wn, '/home/sid/hso.conf');
@@ -994,7 +1008,7 @@ as well as any other error/warning may be tested.
    ($err, $errString) = $measure->getError();
    die $errString."\n" if($err);
 
-To find the sematic relatedness of the first sense of the noun 'car' and
+To find the semantic relatedness of the first sense of the noun 'car' and
 the second sense of the noun 'bus' using the measure, we would write
 the following piece of code:
 
@@ -1009,13 +1023,13 @@ traces are turned off.
 
 =head1 CONFIGURATION FILE
 
-The behaviour of the measures of semantic relatedness can be controlled by
+The behavior of the measures of semantic relatedness can be controlled by
 using configuration files. These configuration files specify how certain
 parameters are initialized within the object. A configuration file may be
 specififed as a parameter during the creation of an object using the new
 method. The configuration files must follow a fixed format.
 
-Every configuration file starts the name of the module ON THE FIRST LINE of
+Every configuration file starts with the name of the module ON THE FIRST LINE of
 the file. For example, a configuration file for the hso module will have
 on the first line 'WordNet::Similarity::hso'. This is followed by the various
 parameters, each on a new line and having the form 'name::value'. The
@@ -1039,21 +1053,24 @@ word#pos#offset strings.
 which case it takes the value 1, i.e. switches 'on' caching. A value of 
 0 switches caching 'off'. By default caching is enabled.
 
+(c) 'maxCacheSize::' -- takes a non-negative integer value. The value indicates
+the size of the cache, used for storing the computed relatedness value.
+
 =head1 SEE ALSO
 
 perl(1), WordNet::Similarity(3), WordNet::QueryData(3)
 
-http://www.d.umn.edu/~patw0006
+http://www.cs.utah.edu/~sidd
 
 http://www.cogsci.princeton.edu/~wn
 
-http://www.ai.mit.edu/people/jrennie/WordNet
+http://www.ai.mit.edu/~jrennie/WordNet
 
 http://groups.yahoo.com/group/wn-similarity
 
 =head1 AUTHORS
 
-  Siddharth Patwardhan, <patw0006@d.umn.edu>
+  Siddharth Patwardhan, <sidd@cs.utah.edu>
   Ted Pedersen, <tpederse@d.umn.edu>
 
 =head1 COPYRIGHT AND LICENSE
