@@ -1,12 +1,14 @@
-# WordNet::Similarity::lch.pm version 0.05
-# (Updated 06/03/2003 -- Sid)
+# WordNet::Similarity::lch.pm version 0.06
+# (Updated 10/10/2003 -- Sid)
 #
-# Semantic Similarity Measure package implementing the semantic 
-# relatedness measure described by Leacock and Chodorow (1998).
+# Semantic Similarity Measure package implementing the measure 
+# described by Leacock and Chodorow (1998).
 #
 # Copyright (c) 2003,
-# Siddharth Patwardhan, University of Minnesota, Duluth
-# patw0006@d.umn.edu
+#
+# Siddharth Patwardhan, University of Utah, Salt Lake City
+# sidd@cs.utah.edu
+#
 # Ted Pedersen, University of Minnesota, Duluth
 # tpederse@d.umn.edu
 #
@@ -44,7 +46,7 @@ use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 
 @EXPORT = ();
 
-$VERSION = '0.05';
+$VERSION = '0.06';
 
 
 # 'new' method for the lch class... creates and returns a WordNet::Similarity::lch object.
@@ -84,6 +86,7 @@ sub new
     $self->{'traceString'} .= "WordNet::Similarity::lch object created:\n";
     $self->{'traceString'} .= "trace :: ".($self->{'trace'})."\n" if(defined $self->{'trace'});
     $self->{'traceString'} .= "cache :: ".($self->{'doCache'})."\n" if(defined $self->{'doCache'});
+    $self->{'traceString'} .= "maxCacheSize :: ".($self->{'maxCacheSize'})."\n" if(defined $self->{'maxCacheSize'});
     # [/trace]
 
     return $self;
@@ -156,6 +159,14 @@ sub _initialize
 			$self->{'doCache'} = 1;
 			$self->{'doCache'} = $tmp if($tmp =~ /^[01]$/);
 		    }
+		    elsif(m/^(?:max)?CacheSize::(.*)/i) 
+		    {
+			my $mcs = $1;
+			$self->{'maxCacheSize'} = 1000;
+			$self->{'maxCacheSize'} = $mcs
+			    if(defined ($mcs) && $mcs =~ m/^\d+$/);
+			$self->{'maxCacheSize'} = 0 if($self->{'maxCacheSize'} < 0);
+		    }
 		    elsif($_ ne "")
 		    {
 			s/::.*//;
@@ -574,7 +585,7 @@ of word senses using the method described by Leacock and Chodorow (1998).
 This module computes the semantic relatedness of word senses according
 to a method described by Leacock and Chodorow (1998). This method counts up
 the number of edges between the senses in the 'is-a' hierarchy of WordNet.
-This value is then scaled by the maximum depth of the WordNet 'is-a'
+The value is then scaled by the maximum depth of the WordNet 'is-a'
 hierarchy. A relatedness value is obtained by taking the negative log
 of this scaled value.
 
@@ -592,7 +603,7 @@ See the WordNet::Similarity(3) documentation for details of these methods.
 =head1 TYPICAL USAGE EXAMPLES
 
 To create an object of the lch measure, we would have the following
-lines of code in the perl program. 
+lines of code in the Perl program. 
 
    use WordNet::Similarity::lch;
    $measure = WordNet::Similarity::lch->new($wn, '/home/sid/lch.conf');
@@ -608,7 +619,7 @@ as well as any other error/warning may be tested.
    ($err, $errString) = $measure->getError();
    die $errString."\n" if($err);
 
-To find the sematic relatedness of the first sense of the noun 'car' and
+To find the semantic relatedness of the first sense of the noun 'car' and
 the second sense of the noun 'bus' using the measure, we would write
 the following piece of code:
 
@@ -623,20 +634,21 @@ traces are turned off.
 
 =head1 CONFIGURATION FILE
 
-The behaviour of the measures of semantic relatedness can be controlled by
+The behavior of the measures of semantic relatedness can be controlled by
 using configuration files. These configuration files specify how certain
 parameters are initialized within the object. A configuration file may be
-specififed as a parameter during the creation of an object using the new
+specified as a parameter during the creation of an object using the new
 method. The configuration files must follow a fixed format.
 
-Every configuration file starts the name of the module ON THE FIRST LINE of
-the file. For example, a configuration file for the lch module will have
-on the first line 'WordNet::Similarity::lch'. This is followed by the various
+Every configuration file starts with the name of the module ON THE
+FIRST LINE of the file. For example, a configuration file for the
+WordNet::Similarity::lch module will have on the first line
+'WordNet::Similarity::lch'. This is followed by the various
 parameters, each on a new line and having the form 'name::value'. The
-'value' of a parameter is optional (in case of boolean parameters). In case
-'value' is omitted, we would have just 'name::' on that line. Comments are
-supported in the configuration file. Anything following a '#' is ignored till 
-the end of the line.
+'value' of a parameter is optional (in case of boolean parameters). In
+case 'value' is omitted, we would have just 'name::' on that
+line. Comments are supported in the configuration file. Anything
+following a '#' is ignored till the end of the line.
 
 The module parses the configuration file and recognizes the following 
 parameters:
@@ -653,21 +665,24 @@ word#pos#offset strings.
 which case it takes the value 1, i.e. switches 'on' caching. A value of 
 0 switches caching 'off'. By default caching is enabled.
 
+(c) 'maxCacheSize::' -- takes a non-negative integer value. The value indicates
+the size of the cache, used for storing the computed relatedness value.
+
 =head1 SEE ALSO
 
 perl(1), WordNet::Similarity(3), WordNet::QueryData(3)
 
-http://www.d.umn.edu/~patw0006
+http://www.cs.utah.edu/~sidd
 
 http://www.cogsci.princeton.edu/~wn
 
-http://www.ai.mit.edu/people/jrennie/WordNet
+http://www.ai.mit.edu/~jrennie/WordNet
 
 http://groups.yahoo.com/group/wn-similarity
 
 =head1 AUTHORS
 
-  Siddharth Patwardhan, <patw0006@d.umn.edu>
+  Siddharth Patwardhan, <sidd@cs.utah.edu>
   Ted Pedersen, <tpederse@d.umn.edu>
 
 =head1 COPYRIGHT AND LICENSE
