@@ -1,11 +1,13 @@
-# WordNet::Similarity::random.pm version 0.05
-# (Updated 06/03/2003 -- Sid)
+# WordNet::Similarity::random.pm version 0.06
+# (Updated 10/10/2003 -- Sid)
 #
 # Random semantic distance generator module.
 #
 # Copyright (c) 2003,
-# Siddharth Patwardhan, University of Minnesota, Duluth
-# patw0006@d.umn.edu
+#
+# Siddharth Patwardhan, University of Utah, Salt Lake City
+# sidd@cs.utah.edu
+#
 # Ted Pedersen, University of Minnesota, Duluth
 # tpederse@d.umn.edu
 #
@@ -43,7 +45,7 @@ use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 
 @EXPORT = ();
 
-$VERSION = '0.05';
+$VERSION = '0.06';
 
 
 # 'new' method for the random class... creates and returns a WordNet::Similarity::random object.
@@ -181,10 +183,12 @@ sub _initialize
 
     # [trace]
     $self->{'traceString'} = "";
-    $self->{'traceString'} .= "WordNet::Similarity::lch object created:\n";
+    $self->{'traceString'} .= "WordNet::Similarity::random object created:\n";
     $self->{'traceString'} .= "trace   :: ".($self->{'trace'})."\n" if(defined $self->{'trace'});
     $self->{'traceString'} .= "cache   :: ".($self->{'doCache'})."\n" if(defined $self->{'doCache'});
     $self->{'traceString'} .= "maxRand :: ".($self->{'maxrand'})."\n" if(defined $self->{'maxrand'});
+    $self->{'traceString'} .= "Switching on caching allows the measure to save random values and\n";
+    $self->{'traceString'} .= "retrieve them later for previously 'seen' pairs of concepts.\n";
     # [/trace]
 }
 
@@ -268,7 +272,7 @@ sub getRelatedness
 
     if(!$offset1 || !$offset2)
     {
-	$self->{'errorString'} .= "\nWarning (WordNet::Similarity::hso->getRelatedness()) - ";
+	$self->{'errorString'} .= "\nWarning (WordNet::Similarity::random->getRelatedness()) - ";
 	$self->{'errorString'} .= "Input senses not found in WordNet.";
 	$self->{'error'} = ($self->{'error'} < 1) ? 1 : $self->{'error'};
 	return undef;
@@ -354,7 +358,7 @@ See the WordNet::Similarity(3) documentation for details of these methods.
 =head1 TYPICAL USAGE EXAMPLES
 
 To create an object of the random measure, we would have the following
-lines of code in the perl program. 
+lines of code in the Perl program. 
 
    use WordNet::Similarity::random;
    $measure = WordNet::Similarity::random->new($wn, '/home/sid/random.conf');
@@ -370,7 +374,7 @@ as well as any other error/warning may be tested.
    ($err, $errString) = $measure->getError();
    die $errString."\n" if($err);
 
-To find the sematic relatedness of the first sense of the noun 'car' and
+To find the semantic relatedness of the first sense of the noun 'car' and
 the second sense of the noun 'bus' using the measure, we would write
 the following piece of code:
 
@@ -385,13 +389,13 @@ traces are turned off.
 
 =head1 CONFIGURATION FILE
 
-The behaviour of the measures of semantic relatedness can be controlled by
+The behavior of the measures of semantic relatedness can be controlled by
 using configuration files. These configuration files specify how certain
 parameters are initialized within the object. A configuration file may be
-specififed as a parameter during the creation of an object using the new
+specified as a parameter during the creation of an object using the new
 method. The configuration files must follow a fixed format.
 
-Every configuration file starts the name of the module ON THE FIRST LINE of
+Every configuration file starts with the name of the module ON THE FIRST LINE of
 the file. For example, a configuration file for the random module will have
 on the first line 'WordNet::Similarity::random'. This is followed by the various
 parameters, each on a new line and having the form 'name::value'. The
@@ -424,17 +428,17 @@ for every word sense pair a new random number will be generated.
 
 perl(1), WordNet::Similarity(3), WordNet::QueryData(3)
 
-http://www.d.umn.edu/~patw0006
+http://www.cs.utah.edu/~sidd
 
 http://www.cogsci.princeton.edu/~wn
 
-http://www.ai.mit.edu/people/jrennie/WordNet
+http://www.ai.mit.edu/~jrennie/WordNet
 
 http://groups.yahoo.com/group/wn-similarity
 
 =head1 AUTHORS
 
-  Siddharth Patwardhan, <patw0006@d.umn.edu>
+  Siddharth Patwardhan, <sidd@cs.utah.edu>
   Ted Pedersen, <tpederse@d.umn.edu>
 
 =head1 COPYRIGHT AND LICENSE
